Supreme and Appellate Opinions

# New Jersey Courts

- Home | Courts | Forms | General Information | Legal | News & Publications | Online Resources | Opinions | Programs & Services | Self-Help Center | Search

## Related Content

- Appellate Division Unpublished Opinions
- Business Related Opinions
- Disciplinary Review Board Decisions
- Opinions Expected for Release
- Trial Court Published Opinions
- Trial Court Unpublished Opinions

## Supreme and Appellate Opinions

Listed on this page are opinions issued by the New Jersey Supreme Court and Appellate Division, Superior Court. These opinions will be made available for 10 business days, after 10 business days you may access the opinions through Rutgers Newark Law School. Opinions are posted in Adobe .pdf. format and require the download of Adobe Reader.

Rutgers Newark Law School hosts a searchable database of New Jersey Supreme Court and Appellate Court reported opinions dating from March 1994 to the present. Also on that web site is a full text archive of the opinions of the Advisory Committee on Professional Ethics, Committee on the Unauthorized Practice of Law, and the Committee on Attorney Advertising.

## Supreme Court Opinions

Date | Appeal # | Title
--- | --- | ---
Aug 13, 2015 | A-67-13 | Citizens United Reciprocal Exchange v. Sabrina A. Perez (073384) (Hudson County and Statewide)
Aug 12, 2015 | A-95-13 | Cuiyan Qian v. Toll Brothers, Inc. (073982) (Middlesex County and Statewide)
Aug 11, 2015 | A-71/72/73-13 | Hon. Dana L. Redd v. Vance Bowman(073567) (Camden County and Statewide)
Aug 10, 2015 | A-84-13 A-2-14 | In the Matter of the Expungement Petition of J.S.(073376) (Monmouth County and Statewide) In the Matter of the Expungement of the Criminal Record of G.P.B. (074541) (Warren County and Statewide)
Aug 07, 2015 | -- | No Supreme Court opinions reported.
Aug 06, 2015 | A-101-13 | John Ross v. Karen A. Lowitz (074200) (Monmouth County and Statewide)
Aug 05, 2015 | A-6-14 | State v. Elise N. Munafo (074142) (Essex County and Statewide)
Aug 04, 2015 | A-69-13 | State v. Dontae Hathaway (073770) (Atlantic County and Statewide)
Aug 03, 2015 | A-92-13 | State v. Duran C. Keaton (073564) (Camden County and Statewide)
July 31, 2015 | -- | No Supreme Court opinions reported.

Squibs: 2013-14 |2012-13 |2011-12 |2010-11 |2009-10 |2008-09 | 2007-08 | 2006-07

## Appellate Court Published Opinions

Date | Docket # | Title
--- | --- | ---
Aug 13, 2015 | -- | No Published Appellate Court opinions reported.
Aug 12, 2015 | A-2270-12T4 | GIVAUDAN FRAGRANCES CORPORATION VS. AETNA CASUALTY & SURETY COMPANY A/K/A TRAVELERS CASUALTY AND SURETY COMPANY, ET AL. (L-592-09, MORRIS COUNTY AND STATEWIDE)
Aug 11, 2015 | A-2114-12T2 | NEW JERSEY DIVISION OF CHILD PROTECTION AND PERMANENCY VS. I.B. AND A.E. IN THE MATTER OF R.B. (FN-07-460-12, ESSEX COUNTY AND STATEWIDE)(RECORD IMPOUNDED)
Aug 11, 2015 | A-5023-12T1 | JOHNNY MEDINA VS. CEASAR G. PITTA, M.D., ET AL. (L-5532-11, HUDSON COUNTY AND STATEWIDE)
Aug 11, 2015 | A-1293-14T2 | J.I. VS. NEW JERSEY STATE PAROLE BOARD (NEW JERSEY STATE PAROLE BOARD) (RECORD IMPOUNDED)
Aug 10, 2015 | A-4439-11T2 A-4705-11T2 A-4713-11T2 | ESTATE OF JACK D'AVILA BY TIAGO D'AVILA, ADMINISTRATOR AD PROSEQUENDUM AND DENISE ROCHA, INDIVIDUALLY VS. HUGO NEU SCHNITZER EAST, ET AL. CONTINENTAL CASUALTY COMPANY VS. AMERICAN HOME ASSURANCE COMPANY, ET AL. CONTINENTAL CASUALTY COMPANY VS. AMERICAN HOME ASSURANCE COMPANY, ET AL. (L-3208-07 AND L-3380-09, MIDDLESEX COUNTY AND STATEWIDE) (CONSOLIDATED)
Aug 07, 2015 | -- | A-1028-13T2 STATE OF NEW JERSEY VS. AMIR RANDOLPH (12-02-0279, HUDSON COUNTY AND STATEWIDE)
Aug 06, 2015 | A-1775-13T1 | TIMBER GLEN PHASE III, LLC AND JSM AT TIMBER GLEN, LLC VS. TOWNSHIP OF HAMILTON (L-0988-12, ATLANTIC COUNTY AND STATEWIDE)
Aug 05, 2015 | -- | No Published Appellate Court opinions reported.
Aug 04, 2015 | -- | No Published Appellate Court opinions reported.
Aug 03, 2015 | -- | No Published Appellate Court opinions reported.
July 31, 2015 | -- | No Published Appellate Court opinions reported.

Squibs: 2014-15 | 2013-14 | 2012-13 |2011-12 |2010-11 |2009-10 |2008-09 | 2007-08 | 2006-07
Privacy Policy | Contact Us | ©
New Jersey Judiciary